translate.misc.typecheck.Tuple

Package translate :: Package misc :: Package typecheck :: Class Tuple |
[hide private]
[frames] | no frames]

# Class Tuple

source code

Instance Methods | [hide private]
__init__(self, *type) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__typecheck__(self, func, to_check) | source code
Inherited from `List`: `__eq__`, `__hash__` Inherited from `CheckType`: `__ne__`, `__repr__`, `__str__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
__typesig__(cls, obj) | source code

Class Variables | [hide private]
| name = ``'``Tuple``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *type) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __typecheck__(self, func, to_check) | source code
Overrides: CheckType.__typecheck__

### __typesig__(cls, obj) Class Method | source code
Overrides: CheckType.__typesig__